package App::stopw;

our $DATE = '2019-06-23'; # DATE
our $VERSION = '0.040'; # VERSION

1;
# ABSTRACT: A console-based virtual stopwatch and timer

__END__

=pod

=encoding UTF-8

=head1 NAME

App::stopw - A console-based virtual stopwatch and timer

=head1 VERSION

This document describes version 0.040 of App::stopw (from Perl distribution App-stopw), released on 2019-06-23.

=head1 SYNOPSIS

This distribution provides the L<stopw> command-line utility.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-stopw>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-stopw>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-stopw>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2016, 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
